Downloads
===========

.. only:: builder_html

    Download files directly from here:

    * :download:`seriesmgmt27.pex <../dist/seriesmgmt27.pex>`
    * :download:`seriesmgmt35.pex <../dist/seriesmgmt35.pex>`